@@ -70,7 +70,7 @@ meta_window_release_saved_state (const MetaWindowSessionInfo *info)
 #include <stdio.h>
 #include "main.h"
 #include "util.h"
-#include "display.h"
+#include "display-private.h"
 #include "workspace.h"
 
 static void ice_io_error_handler (IceConn connection);
